@@ -4,7 +4,7 @@ import json
 import logging
 import sys
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 import annofabapi
 import pandas
@@ -17,6 +17,7 @@ from annofabcli.common.cli import (
     ArgumentParser,
     build_annofabapi_resource_and_login,
     get_json_from_args,
+    get_list_from_args,
     get_wait_options_from_args,
 )
 from annofabcli.common.dataclasses import WaitOptions
@@ -28,15 +29,17 @@ logger = logging.getLogger(__name__)
 DEFAULT_WAIT_OPTIONS = WaitOptions(interval=60, max_tries=360)
 
 
-class ListInputDataMergedTask(AbstractCommandLineInterface):
-    def __init__(self, service: annofabapi.Resource, facade: AnnofabApiFacade, args: argparse.Namespace):
-        super().__init__(service, facade, args)
+def millisecond_to_hour(millisecond: int):
+    return millisecond / 1000 / 3600
+
+
+class ListInputDataMergedTaskMain:
+    def __init__(self, service: annofabapi.Resource):
+        self.service = service
+        self.facade = AnnofabApiFacade(service)
 
     @staticmethod
-    def millisecond_to_hour(millisecond: int):
-        return millisecond / 1000 / 3600
-
-    def _to_task_list_based_input_data(self, task_list: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+    def _to_task_list_based_input_data(task_list: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
         new_all_task_list: List[Dict[str, Any]] = []
         for task in task_list:
             for input_data_id in task["input_data_id_list"]:
@@ -44,22 +47,55 @@ class ListInputDataMergedTask(AbstractCommandLineInterface):
                     "task_id": task["task_id"],
                     "status": task["status"],
                     "phase": task["phase"],
-                    "worktime_hour": self.millisecond_to_hour(task["work_time_span"]),
+                    "worktime_hour": millisecond_to_hour(task["work_time_span"]),
                     "input_data_id": input_data_id,
                 }
                 new_all_task_list.append(new_task)
         return new_all_task_list
 
-    def print_input_data_merged_task(self, input_data_list: List[Dict[str, Any]], task_list: List[Dict[str, Any]]):
+    @staticmethod
+    def _filter_input_data(
+        df_input_data: pandas.DataFrame,
+        input_data_id_list: Optional[List[str]] = None,
+        input_data_name_list: Optional[List[str]] = None,
+    ):
+        df = df_input_data
+        if input_data_id_list is not None:
+            df = df[df["input_data_id"].isin(input_data_id_list)]
+
+        if input_data_name_list is not None:
+            df = pandas.concat(
+                [
+                    df[df["input_data_name"].str.lower().str.contains(input_data_name.lower())]
+                    for input_data_name in input_data_name_list
+                ]
+            )
+        return df
+
+    def create_input_data_merged_task(
+        self,
+        input_data_list: List[Dict[str, Any]],
+        task_list: List[Dict[str, Any]],
+        input_data_id_list: Optional[List[str]] = None,
+        input_data_name_list: Optional[List[str]] = None,
+    ):
         new_task_list = self._to_task_list_based_input_data(task_list)
 
         df_input_data = pandas.DataFrame(input_data_list)
+        df_input_data = self._filter_input_data(
+            df_input_data, input_data_id_list=input_data_id_list, input_data_name_list=input_data_name_list
+        )
+
         df_task = pandas.DataFrame(new_task_list)
+
         df_merged = pandas.merge(df_input_data, df_task, how="left", on="input_data_id")
 
-        annofabcli.utils.print_according_to_format(
-            df_merged, arg_format=FormatArgument(FormatArgument.CSV), output=self.output, csv_format=self.csv_format
-        )
+        return df_merged
+
+
+class ListInputDataMergedTask(AbstractCommandLineInterface):
+    def __init__(self, service: annofabapi.Resource, facade: AnnofabApiFacade, args: argparse.Namespace):
+        super().__init__(service, facade, args)
 
     @staticmethod
     def validate(args: argparse.Namespace) -> bool:
@@ -75,7 +111,8 @@ class ListInputDataMergedTask(AbstractCommandLineInterface):
             args.input_data_json is not None and args.task_json is None
         ):
             print(
-                f"{COMMON_MESSAGE} '--task_json'と'--input_data_json'の両方を指定する必要があります。", file=sys.stderr,
+                f"{COMMON_MESSAGE} '--task_json'と'--input_data_json'の両方を指定する必要があります。",
+                file=sys.stderr,
             )
             return False
 
@@ -104,7 +141,7 @@ class ListInputDataMergedTask(AbstractCommandLineInterface):
 
         project_id = args.project_id
         if project_id is not None:
-            super().validate_project(project_id, [ProjectMemberRole.OWNER])
+            super().validate_project(project_id, [ProjectMemberRole.OWNER, ProjectMemberRole.TRAINING_DATA_USER])
             wait_options = get_wait_options_from_args(get_json_from_args(args.wait_options), DEFAULT_WAIT_OPTIONS)
             cache_dir = annofabcli.utils.get_cache_dir()
             self.download_json_files(project_id, cache_dir, args.latest, wait_options)
@@ -120,7 +157,19 @@ class ListInputDataMergedTask(AbstractCommandLineInterface):
         with open(input_data_json_path, encoding="utf-8") as f:
             input_data_list = json.load(f)
 
-        self.print_input_data_merged_task(input_data_list=input_data_list, task_list=task_list)
+        input_data_id_list = get_list_from_args(args.input_data_id) if args.input_data_id is not None else None
+        input_data_name_list = get_list_from_args(args.input_data_name) if args.input_data_name is not None else None
+
+        main_obj = ListInputDataMergedTaskMain(self.service)
+        df_merged = main_obj.create_input_data_merged_task(
+            input_data_list=input_data_list,
+            task_list=task_list,
+            input_data_id_list=input_data_id_list,
+            input_data_name_list=input_data_name_list,
+        )
+        annofabcli.utils.print_according_to_format(
+            df_merged, arg_format=FormatArgument(FormatArgument.CSV), output=self.output, csv_format=self.csv_format
+        )
 
 
 def main(args):
@@ -166,6 +215,11 @@ def parse_args(parser: argparse.ArgumentParser):
         "`max_tires`:完了したかの問い合わせを最大何回行うか。",
     )
 
+    parser.add_argument("-i", "--input_data_id", type=str, nargs="+", help="指定したinput_data_idに完全一致する入力データを絞り込みます。")
+    parser.add_argument(
+        "--input_data_name", type=str, nargs="+", help="指定したinput_data_nameに部分一致(大文字小文字区別しない）する入力データを絞り込みます。"
+    )
+
     argument_parser.add_output()
     argument_parser.add_csv_format()
 
@@ -176,7 +230,7 @@ def add_parser(subparsers: argparse._SubParsersAction):
     subcommand_name = "list_merged_task"
     subcommand_help = "タスク一覧と結合した入力データ一覧のCSVを出力します。"
     description = "タスク一覧と結合した入力データ一覧のCSVを出力します。"
-    epilog = "オーナロールを持つユーザで実行してください。"
+    epilog = "アノテーションユーザまたはオーナロールを持つユーザで実行してください。"
 
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, epilog=epilog)
     parse_args(parser)
